; determine if I'm running Emacs 21 or 20, and change accordingly
(setq crs-v21 (eq emacs-major-version 21))

(setq load-path (cons (expand-file-name "/usr/local/share/emacs/21.2/lisp/") load-path))
(setq Info-directory-list (cons "/home/idb/documents/"
                                (cons "/home/idb/info/"
                                      Info-default-directory-list)))
(add-to-list 'load-path "~/lib/emacs/")
(add-to-list 'load-path "/usr/local/share/emacs/site-lisp/w3m/")
(add-to-list 'load-path "~/lib/emacs/auctex/")
(add-to-list 'load-path "/usr/local/share/emacs/21.2/site-list/preview")
(add-to-list 'load-path "~/lib/emacs/speedbar-1.4")
(add-to-list 'load-path "~/lib/emacs/eieio")
(add-to-list 'load-path "~/lib/emacs/semantic")
(add-to-list 'load-path "~/lib/emacs/EDE")
(add-to-list 'load-path "~/lib/emacs/ecb")

; Emacs/W3 Configuration
(setq load-path (cons "/usr/local/share/emacs/site-lisp" load-path))
(condition-case () (require 'w3-auto "w3-auto") (error nil))

; Turn off Emacs 21 toolbar
(if (fboundp 'tool-bar-mode)
    (tool-bar-mode -1))

(scroll-bar-mode -1)
(display-time)
(column-number-mode 1)
(line-number-mode 1)
(standard-display-european 1)

(defun my-font-lock ()
  (if window-system
      (if (x-display-color-p)
          (turn-on-font-lock))))
;(setq debug-on-error t)

(add-hook 'c-mode-hook
          '(lambda nil
             (c-set-style "K&R")
             (auto-fill-mode 1)
             (set-fill-column 79)
             (my-font-lock)
             ))
(add-hook 'c++-mode-hook
          '(lambda nil
             (c-set-style "gnu")
             (auto-fill-mode 1)
             (set-fill-column 79)
             (my-font-lock)
             ))
(add-hook 'java-mode-hook
          '(lambda nil
             (auto-fill-mode 1)
             (set-fill-column 79)
             (my-font-lock)
             ))
(add-hook 'tex-mode-hook
          '(lambda nil
             (auto-fill-mode 1)
             (set-fill-column 70)
             (my-font-lock)))
(add-hook 'asm-mode-hook 'my-font-lock)
(add-hook 'perl-mode-hook 'my-font-lock)
(add-hook 'makefile-mode-hook 'my-font-lock)
(add-hook 'scheme-mode-hook 'my-font-lock)
(add-hook 'lisp-mode-hook 'my-font-lock)
(add-hook 'emacs-lisp-mode-hook 'my-font-lock)
(add-hook 'html-helper-mode-hook 'my-font-lock)
(add-hook 'mh-letter-mode-hook
          '(lambda nil
             (auto-fill-mode 1)
             (set-fill-column 70)
             (iso-accents-mode 1)
             ))

(setq auto-mode-alist
      (append (list
               (cons "\\.i\$"      'c-mode)
               (cons "\\.in"       'makefile-mode)
               (cons "\\.md"       'c-mode)
               (cons "\\.tc"       'c-mode)
               (cons "\\.click"    'c++-mode)
               (cons "\\.txt"      'text-mode)
               (cons "\\.lg"       'tex-mode)) ; lgrind
              auto-mode-alist))

; useful bindings
(define-key esc-map "r" 'replace-string)
(global-set-key "\M-\C-g" 'goto-line)
(global-set-key "\C-x\C-c" 'exit-emacs-with-confirm)
(global-set-key "\M-\t" 'self-insert-command)
(global-set-key "\M-\C-p" 'spell-buffer)
(global-set-key [(f4)] 'speedbar-get-focus)
(global-set-key "\C-C\C-C" 'compile)
(global-set-key "\C-C\C-E" 'load-dot-emacs)
(global-set-key "\C-x\C-b" 'idb-list-buffers)
(global-set-key "\M-]" 'idb-frame-toggle-wide-display)
(global-set-key "\M-{" 'raise-frame)
(global-set-key "\M-}" 'lower-frame)


(defun load-dot-emacs ()
    (interactive)
    (load-file "/home/idb/.emacs"))

    (put 'eval-expression 'disabled nil)

(defun idb-list-buffers ()
  "List buffers in current window and places cursor on displaced buffer"
  (interactive)

  (let ((bufnam (buffer-name)))
    (save-window-excursion (list-buffers))  ;; list-buffers in background
    (switch-to-buffer "*Buffer List*")      ;; bring buffer list forward
    (beginning-of-buffer)                   ;; start displaced buffer search
    (search-forward (concat " " bufnam) nil t)  ;; at the top of the buffer
;   (re-search-forward (concat bufnam "\t\\|" bufnam "  "))
    (beginning-of-line)                     ;; clean up display
))
  
; calendar/diary
(add-hook 'diary-hook 'appt-make-list)
(setq diary-file (expand-file-name "~/.diary")
      appt-message-warning-time 20
      number-of-diary-entries 7
      diary-mail-days 7
      diary-mail-addr "idb@localhost")

; random
(setq enable-local-variables 1)
(setq check-for-extended-command-bindings t)
(setq minibuffer-max-depth nil)
(setq next-line-add-newlines nil)
(setq version-control 'never)
(setq backup-by-copying-when-linked t)

; disable novice mode
(put 'eval-expression 'disabled nil)
(put 'narrow-to-page 'disabled nil)
(put 'narrow-to-region 'disabled nil)
(put 'downcase-region 'disabled nil)
(setq enable-recursive-minibuffers t)
(setq inhibit-startup-message t)
(setq truncate-lines nil)
(setq truncate-partial-width-windows truncate-lines)

; mh-rmail
(defun mhm () (interactive) (mh-rmail))
(setq mh-recursive-folders-flag t)
(setq mh-signature-file-name "~/.signature")
(setq mh-alias-timestamp '("~/Mail/aliases" "/etc/passwd"))
(setq e-mh-alias-flash-on-comma nil)
(setq e-mh-alias-local-users nil)
(require `mh-alias)
(require `mime-setup)

;  mailcrypt
;(add-hook 'mh-folder-mode-hook 'mc-install-read-mode)
;(add-hook 'mh-letter-mode-hook 'mc-install-write-mode)
;(load-library "mailcrypt")
;(mc-setversion "gpg")
;(setq mc-encrypt-for-me t)
;(setq mc-pgp-always-sign t)
;(setq mc-gpg-always-fetch t)
;(setq mc-pgp-keyserver-address "wwwkeys.us.pgp.net")
;(setq mc-pgp-keyserver-port 11371)
;(setq mc-pgp-keyserver-url-template "/pks/lookup?op=get&search=%s")

;; enable w3m & mime-html (from w3m package)
(autoload 'w3m "w3m" "Interface for w3m on Emacs." t)
(autoload 'w3m-browse-url "w3m" "w3m interface function for browse-url.el." t)
(setq w3m-fill-column -5)
(setq browse-url-browser-function 'w3m-browse-url)
(setq mime-setup-enable-inline-html nil)
(eval-after-load "mime-view"
'(progn
(autoload 'mime-w3m-preview-text/html "mime-w3m")
(ctree-set-calist-strictly
'mime-preview-condition
'((type . text)
(subtype . html)
(body . visible)
(body-presentation-method .
mime-w3m-preview-text/html)))
(set-alist 'mime-view-type-subtype-score-alist
'(text . html) 1))) 
;; w3 link listings
(autoload 'w3-speedbar-buttons "sb-w3" "s3 specific speedbar button generator.")

; gnus
(setq gnus-nntp-server "news.carnet.hr"
      gnus-nntp-server "freebsd.csie.nctu.edu.tw"
      gnus-article-save-directory "~/news"
      gnus-novice-user  nil)

; code
(defun highlight-region (string)
  "Inserts STRING at the beginning of every line in the region.
   Called interactively, STRING defaults to '> ' unless a prefix
   argument is given."
  (interactive (list (if current-prefix-arg
                         (read-string "String to insert: ")
                       " > ")))
  (save-excursion
    (if (bolp)
        (forward-line -1))
    (save-restriction
      (narrow-to-region (point) (mark))
      (goto-char (point-min))
      (replace-regexp "^" string))))

(defun exit-emacs-with-confirm ()
  (interactive)
  (if (yes-or-no-p "Do you really want to exit? ")
      (save-buffers-kill-emacs)))

;AucTex
(require 'tex-site)
(load "/usr/local/share/emacs/21.2/site-lisp/preview/preview-latex.el")

;window-resize
(require 'idb-frame)

;speedbar-1.4
(autoload 'speedbar-frame-mode "speedbar" "Popup a speedbar frame" t)
(autoload 'speedbar-get-focus "speedbar" "Jump to speedbar frame" t)

; emacsserver
(server-start)

;semantic
(setq semantic-load-turn-everything-on t)
(autoload 'semantic-map-buffers "semantic-util")
(require 'semantic-load)

;ecb
(require 'ecb)

;windmove
(require 'windmove)
(windmove-default-keybindings)
(setq windmove-wrap-around t)

;iswitchb-mode
(custom-set-variables
 '(iswitchb-mode t nil (iswitchb)))
(custom-set-faces)

;loading irc client
;(require 'erc)


(diary)

